# Willkommen!

Wie es aussieht, bist Du neu bei OpenSesame 3.

Falls Du OpenSesame noch nie benutzt hast, empfehle ich Dir das Tutorial für Anfänger durchzugehen. Das wird zunächst ein wenig Zeit kosten, zahlt sich später aber durch große Zeitersparnis wieder ein.

[Tutorial](new:http://osdoc.cogsci.nl/3.2/tutorials/beginner){: .important-button}

Wenn Du OpenSesame 2 schon benutzt hast, empfehle ich Dir kurz anzuschauen, was es Neues gibt seit Version 3 (Dies ist Version 3.2). Keine Sorge: Deine alten Experimente funktionieren weiterhin, und alles andere ist nur noch einfacher geworden.

[Anschauen was es Neues gibt bei OpenSesame 3](new:http://osdoc.cogsci.nl/3.2/important-changes-3){: .button}

Und vergiss nicht, dass Du jederzeit Deine Fragen in unserem Support-Forum (Englisch) stellen kannst.

[Support-Forum](new:http://forum.cogsci.nl/){: .button}

Oder:

[Diese Nachricht dauerhaft ausblenden](opensesame://event.os3n_dismiss_startup){: .dismiss-button}
